/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef nsUCvTWDll_h___
#define nsUCvTWDll_h___

#include "prtypes.h"

extern const uint16_t g_ufBig5Mapping[];
extern const uint16_t g_utBIG5Mapping[];
extern const uint16_t g_ASCIIMappingTable[];
extern const uint16_t g_ufBig5HKSCSMapping[];
extern const uint16_t g_utBig5HKSCSMapping[];

#endif /* nsUCvTWDll_h___ */
